@@ -80,6 +80,8 @@ class DancingBarsSettings : public KPageDialog
     void setSensors( const SensorModelEntry::List &list );
     SensorModelEntry::List sensors() const;
 
+    QList<uint> getDeletedIds();
+
   private Q_SLOTS:
     void editSensor();
     void removeSensor();
@@ -100,6 +102,8 @@ class DancingBarsSettings : public KPageDialog
     QPushButton *mEditButton;
     QPushButton *mRemoveButton;
 
+    QList<uint> deletedIds;
+
     QTreeView *mView;
     SensorModel *mModel;
 };
