@@ -20,21 +20,20 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <QApplication>
+#include <QDebug>
 #include <QtXml/qdom.h>
 #include <QToolTip>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QLabel>
+#include <QLocale>
 #include <QResizeEvent>
+#include <QStandardPaths>
 
-
-#include <kdebug.h>
-#include <KGlobal>
 #include <KLocalizedString>
 #include <kmessagebox.h>
-#include <kapplication.h>
 #include <ksignalplotter.h>
-#include <kstandarddirs.h>
 
 #include <ksgrd/SensorManager.h>
 #include "StyleEngine.h"
@@ -81,7 +80,7 @@ class FancyPlotterLabel : public QLabel {
         resizeEvent(NULL);
         update();
     }
-    virtual void resizeEvent( QResizeEvent * ) {
+    void resizeEvent( QResizeEvent * ) Q_DECL_OVERRIDE {
         QFontMetrics fm = fontMetrics();
 
         if(valueText.isEmpty()) {
@@ -116,7 +115,7 @@ class FancyPlotterLabel : public QLabel {
     void changeLabel(const QColor &_color) {
         color = _color;
 
-        if ( kapp->layoutDirection() == Qt::RightToLeft )
+        if ( QApplication::layoutDirection() == Qt::RightToLeft )
             longHeadingText = QStringLiteral(": ") + labelName + " <font color=\"" + color.name() + "\">" + indicatorSymbol + "</font>";
         else
             longHeadingText = QStringLiteral("<qt><font color=\"") + color.name() + "\">" + indicatorSymbol + "</font> " + labelName + " :";
@@ -448,7 +447,7 @@ bool FancyPlotter::addSensor( const QString &hostName, const QString &name,
 bool FancyPlotter::removeBeam( uint beamId )
 {
     if ( beamId >= mBeams ) {
-        kDebug(1215) << "FancyPlotter::removeBeam: beamId out of range ("
+        qDebug() << "FancyPlotter::removeBeam: beamId out of range ("
             << beamId << ")" << endl;
         return false;
     }
@@ -514,7 +513,7 @@ void FancyPlotter::setTooltip()
             description = sensor->name();
 
         if(sensor->isOk()) {
-            lastValue = KLocale::global()->formatNumber( sensor->lastValue, (sensor->isInteger)?0:-1 );
+            lastValue = QLocale().toString( sensor->lastValue, (sensor->isInteger)?0:-1 );
             if (sensor->unit() == QLatin1String("%"))
                 lastValue = i18nc("units", "%1%", lastValue);
             else if( !sensor->unit().isEmpty() )
@@ -585,7 +584,7 @@ void FancyPlotter::sendDataToPlotter( )
                         lastValue = mPlotter->lastValueAsString(beamId, precision);
                     } else {
                         precision = (sensor->isInteger)?0:-1;
-                        lastValue = KLocale::global()->formatNumber( mPlotter->lastValue(beamId), precision );
+                        lastValue = QLocale().toString( mPlotter->lastValue(beamId), precision );
                         if (sensor->unit() == QLatin1String("%"))
                             lastValue = i18nc("units", "%1%", lastValue);
                         else if( !sensor->unit().isEmpty() )  {
@@ -786,8 +785,7 @@ bool FancyPlotter::restoreSettings( QDomElement &element )
 
     QString filename = element.attribute( QStringLiteral("svgBackground"));
     if (!filename.isEmpty() && filename[0] == '/') {
-        KStandardDirs* kstd = KGlobal::dirs();
-        filename = kstd->findResource( "data", "ksysguard/" + filename);
+        filename = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "ksysguard/" + filename);
     }
     mPlotter->setSvgBackground( filename );
     if(version >= 1) {
